@@ -1,9 +1,6 @@
 #include <iostream>
 #include <sigc++/sigc++.h>
 
-#include <stdlib.h>
-#include <string.h>
-
 void Foo(sigc::trackable &t) {}
 
 int main(int argc, char **argv)
