@@ -8,11 +8,14 @@
 #include <sigc++/functors/slot.h>
 #include <sigc++/functors/mem_fun.h>
 
+SIGC_USING_STD(cout)
+SIGC_USING_STD(endl)
+
 class my_class: public sigc::trackable
 {
-  public:
-    int i;
-    virtual void foo() { std::cout << i << std::endl; }
+public:
+  int i;
+  void foo() { std::cout << i << std::endl; }
 };
 
 int main()
@@ -20,11 +23,10 @@ int main()
   sigc::slot<void> sl;
   {
     my_class t;
-    t.i=10;
+    t.i = 10;
     sl = sigc::mem_fun0(&t, &my_class::foo);
     sl();
   }
-  int i=0;
 
   sl();
 }
